local Procodile = LibStub("AceAddon-3.0"):GetAddon("Procodile")
local L = LibStub("AceLocale-3.0"):GetLocale("Procodile", false)

ProcodileLDB = Procodile:NewModule("ProcodileLDB")

local ldb = LibStub:GetLibrary("LibDataBroker-1.1")

local dataobj = ldb:NewDataObject("Procodile", {type = "data source", icon = "Interface\\Icons\\Spell_Holy_WordFortitude", text = ""})

function ProcodileLDB:UpdateText(enabled)
	if enabled then
		ldbtext = "Enabled"
	else
		ldbtext = "Disabled"
	end
end

function dataobj:OnTooltipShow()

    self:AddLine(L["Procodile"])
    self:AddLine(" ")
    
    local tracked = Procodile:GetTrackedSpells()
    
	for internalname,proc in pairs(tracked) do
		-- PPM
		local ppm = 0
		if proc.count > 0 then
			ppm = proc.count / (proc.totaltime / 60)
		end
		
		-- Uptime
		local uptime = 0
		if proc.seconds > 0 and proc.totaltime > 0 then
			uptime = proc.seconds / proc.totaltime * 100
		end
				
		self:AddLine(proc.name, 0.3, 0.3, 0.8)
		self:AddTexture(proc.icon)
		if proc.count > 0 then
		    self:AddDoubleLine(L["Procs"], proc.count, nil, nil, nil, 1,1,1)
		else
		    self:AddDoubleLine(L["Procs"], "none", nil, nil, nil, 1,1,1)
		end
			
	    if ppm > 0 then
		    self:AddDoubleLine(L["PPM"], string.format("%.2f", ppm), nil, nil, nil, 1,1,1)
		else
		    self:AddDoubleLine(L["PPM"],"unknown", nil, nil, nil, 1,1,1)
		end
		
		if uptime > 0 then
		    self:AddDoubleLine(L["Uptime"], string.format("%.2f", uptime).."%", nil, nil, nil, 1,1,1)
		else
		    self:AddDoubleLine(L["Uptime"], "unknown", nil, nil, nil, 1,1,1)
		end
		
	    if proc.cooldown > 0 then
		    self:AddDoubleLine(L["Cooldown"], proc.cooldown.."s", nil, nil, nil, 1,1,1)
		else
		    self:AddDoubleLine(L["Cooldown"], "unknown", nil, nil, nil, 1,1,1)
		end
		self:AddLine(" ")
	end

    self:AddLine(L["Hint: Ctrl-Click to reset."], 0, 1, 0)
    self:AddLine(L["Shift-click to toggle tracking."], 0, 1, 0)
    self:AddLine(L["Right-click to configure"], 0, 1, 0)
end

function dataobj:OnEnter()
    GameTooltip:SetOwner(self, "ANCHOR_NONE")
    GameTooltip:SetPoint("TOPLEFT", self, "BOTTOMLEFT")
    GameTooltip:ClearLines()
    dataobj.OnTooltipShow(GameTooltip)
    GameTooltip:Show()
end

function dataobj:OnLeave()
    GameTooltip:Hide()
end

function dataobj:OnClick(button)
	if button == "LeftButton" and IsShiftKeyDown() then
		Procodile:Toggle()
	elseif button == "LeftButton" and IsControlKeyDown() then
		Procodile:Reset()
	elseif button == "RightButton" then
		Procodile:OpenOptions()
	end
end

